@@ -1,7 +1,5 @@
 from pathlib import Path
 from typing import Optional
-from yaml import load, Loader
-
 
 from starpack import initialize, __version__, utils
 from starpack.client import StarpackClient
@@ -12,10 +10,6 @@ def upload(directory: Path, client: Optional[StarpackClient] = None) -> None:
     """
     Uploads the contents of a local directory to the Starpack Engine
     """
-    try:
-        directory = Path(directory)
-    except:
-        return
 
     if not client:
         client = StarpackClient(start=True, docker=True)
@@ -23,22 +17,25 @@ def upload(directory: Path, client: Optional[StarpackClient] = None) -> None:
     client.upload_artifacts(directory=directory)
 
 
-def init(directory: Optional[Path] = None, force: bool = True) -> StarpackClient:
+def initialize_directory(directory: Path, overwrite: bool = False) -> None:
     """
     Starts the starpack-engine container locally and furthermore initializes
     the given directory if given with starter code, an example
     requirements.txt, and an example starpack.yaml
     """
-
-    StarpackClient(start=True, docker=True, force=force)
-
-    # Create the directory if given
     if directory:
         directory = directory.resolve()
         directory.mkdir(parents=True, exist_ok=True)
-        initialize.initialize_project_files(directory)
+        initialize.initialize_project_files(directory, overwrite=overwrite)
 
-    return StarpackClient
+
+def initialize_engine(force: bool = True) -> StarpackClient:
+    """
+    Starts the Starpack Engine. If given an image name, will initialize that image. If given
+    """
+    client = StarpackClient(start=True, docker=True, force=force)
+
+    return client
 
 
 def terminate(
@@ -118,5 +115,3 @@ def deploy_directory(directory: Path, client: Optional[StarpackClient] = None) -
 
     package_directory(directory, client=client)
     deploy(yaml_file, client=client)
-
-    return yaml_file
